@@ -70,9 +70,16 @@ Graphics::Graphics( DG *dg, int argc, char **argv ) throw (class GraphicsExcepti
         PTR_DEFAULT_DISPLAY_LIST_IDX = 0;
 
         _use3dfx = false;
+
+        // windows users get fullscreen default
         
+#ifdef WIN32
+        _fullscreen = true;
+        _videoMode._flags |= SDL_FULLSCREEN;
+#else
         _fullscreen = false;
-        
+#endif
+     
         _dg = dg;
 
         _loopStarted = false;
@@ -137,13 +144,19 @@ Graphics::Graphics( DG *dg, int argc, char **argv ) throw (class GraphicsExcepti
                         }
                 }
                 
-		if ( strcmp(argv[i], "-fullscreen") == 0 ) {
+		if ( strcmp(argv[i], "-fullscreen" ) == 0 ) {
                         _fullscreen = true;
+			_videoMode._flags |= SDL_FULLSCREEN;
 #ifdef GLX
                         _use3dfx = true;
                         putenv( "MESA_GLX_FX=f" );
 #endif
-			_videoMode._flags |= SDL_FULLSCREEN;
+                        continue;
+		}
+                
+		if ( strcmp(argv[i], "-windowed" ) == 0 ) {
+                        _fullscreen = false;
+			_videoMode._flags &= ~SDL_FULLSCREEN;
                         continue;
 		}
                 
@@ -380,7 +393,10 @@ void Graphics::updateGraphics() {
                 
                         glPopMatrix();
                         glTranslatef( 0, _videoMode._height - 48, 0 );
-                        sprintf( buf, " %10s: %3d ms: %3d fps", "physics", g_state.physics_time, g_state.physics_fps );
+                        sprintf( buf, " %10s: %3d ms: %4d fps, %04d deficit", "physics", 
+                                 g_state.physics_time,
+                                 g_state.physics_fps,
+                                 g_state.physics_deficit );
                         font->drawStringFragment( buf, 0, strlen( buf ) );
                 
                         font->endStringDraw();
