@@ -2125,7 +2125,7 @@ bool DungeonScreen::mouseReleased( SDL_MouseButtonEvent * evt ) {
 // class MouseMotionListener {
 bool DungeonScreen::mouseMoved(    SDL_MouseMotionEvent * evt ) {
 
-        static int center[2] = { 
+        static const int center[2] = { 
                 _size[0] / 2, 
                 _size[1] / 2 
         };
